@@ -1,3 +1,14 @@
+
+try:
+    import importlib.resources as pkg_resources
+except ImportError:
+    # PY<37 `importlib_resources`.
+    import importlib_resources as pkg_resources
+
+from templates import aws
+
+
+
 class DeployerRepositoryTemplate:
     """Create a repository for continuous integration of deployer"""
 
@@ -21,7 +32,8 @@ class DeployerRepositoryTemplate:
                     "account-id": config.get("aws", "account", None),
                     "deployment-role": config.get("aws", "deployment_role", ""),
                 },
-                "location": "./templates/aws/deployer-repository.yaml",
+                #"location": "./templates/aws/deployer-repository.yaml",
+                "location": pkg_resources.open_text(aws, 'deployer-repository.yaml'),
                 "template": {
                     "name": cls.name(deployer),
                     "parameters": {
